<?
/* STR_SOCKA 1.0 BY STRANNIK WWW.4IKU.RU */


require'config.php';
$align=$set['alignpr'];
$title='Никто не забыт ничто не забыто!'.date("H:i", $time);
aut();
head();
echo menu.'<b>Реклама</b>'.div;


$query = @mysql_query ("select * from `adv` where `in` = '1' order by `id` asc" );
while( FALSE !== ( $fetch = mysql_fetch_array( $query ) ) )
{
if( !empty( $fetch['color'] ) )
{
$font = '<font color="' . $fetch['color'] . '">';
$cfont = '</font>';
}
else
{
$font = '';
$cfont = '';
}
echo '<a href="http://' . $fetch['url'] . '">' . $font . $fetch['name'] . $cfont . '</a><br/>';
}

if(isset($_GET['intim']))unset($_SESSION['inps']);
if ($user['level']>6)echo head0.'<div align="right"><a href="admin/"><b><font color="#ff0000">Aдмин</font></b></a> управление<br/><br /></div>'.div;
echo '<center><img src="style/images/logo.png" alt="logo"></center> ';
echo foot1.'<div align="left"><a href="my/index">Личный кабинет</a> | <a href="'.H.'faq">Информация</a> | <a href="exit">Выход</a><br/></div>'.div;
echo gend.' Развлекуха у нас :)'.div;

if (empty($user['max'])) $user['max']=10;
$max = $user['max'];
$vip_us = mysql_result(mysql_query("SELECT COUNT(*) FROM `us_vip`"), 0);
$k_page=k_page($vip_us,$max);
$page=page($k_page);
$start=$max*$page-$max;

$r = $db->sql_query ("Select * from us_vip order by id LIMIT $start, 3");
if ($vip_us == 0)echo '<br />Список пуст...<br />';
else{
echo rowup.'<b>VIP пользователей: </b><b>'.$vip_us.'</b> чел.<br />';
if (($max*$page)<$vip_us) $maxi = $max*$page; else $maxi = $vip_us;
echo '<a href="us_vip">Все VIPы  &#187;</a>'.div;
}
$post_k=$start+1;
while($vip = @$db->sql_fetchrow($r)){

echo head0.'<b>'.nik($vip[user_id]).'</b> ';
$user_st = mysql_fetch_assoc(mysql_query("SELECT * FROM `users` WHERE `id` = '".$vip['user_id']."'"));
echo "<br><font color='#FF0000'><b>".$user_st['status']."</b></font><br/>".div;
echo '<dl></dl>';

}
//echo '&#187; <a href="us_vip">Все VIP'ы >></a>';

echo rowup.'&#187; <a href="forum/index"><b>Форум</b></a> <a href="forum/new_t"><span style="color:#ff0000">'.$db->sql_fetchfield($db->sql_query("SELECT COUNT(*) FROM `forum_t`;"), 0).'</span></a> / <a href="forum/new_p"><span style="color:#ff0000">'.$db->sql_fetchfield($db->sql_query("SELECT COUNT(*) FROM `forum_msg`;"), 0).'</span></a></br>';
$num = $db->sql_numrows($db->sql_query( "select id from forum_msg where t_id = '$t' and r_id = '$fid'" ));
$forum=$db->sql_fetchrow($db->sql_query("SELECT * FROM `forum_f` WHERE `id` = '$tem[f_id]' LIMIT 1"));
$razdel=$db->sql_fetchrow($db->sql_query("SELECT * FROM `forum_r` WHERE `id` = '$tem[r_id]' LIMIT 1"));
if (empty ($user['min'])) $user['min']=1; $min = $user['min']; $r = $db->sql_query ("Select * from forum_t order by time desc LIMIT 5"); while($a = @$db->sql_fetchrow ($r)){
echo '&#8226; <a href="forum/tema_'.$a['id'].'">'.$a['name'].' </a>  <a href="forum/tema_'.$a['id'].'_end"> >></a><br />';}
echo div;

switch($mod){

default:

$db->sql_fetchfield($db->sql_query("select count(*) as num from news"),0);

$r = $db->sql_query ("Select * from news order by time desc LIMIT 1");

while($a = @$db->sql_fetchrow($r)){

echo menu.'<img src="img/news.gif"> Новость: '.times($a['time']).'<br/>'.div;

//if (strlen(text($a['msg'])))echo '<br /><a href="news">Читать все &gt;&gt;</a>';
echo text($a[msg]);

echo '<br/><b>Разместил: </b>'.nik($a[user_id]).'<br />';

echo '
<a href="news?mod=komm&new='.$a[id].'">Комментарии</a>('.$db->sql_fetchfield($db->sql_query("select count(*) as num from newskom where new = '".$a[id]."'"),0).')';

}

}

echo rowup.'<img src="http://wapmas.ru/pic/ico/dl/People_Icons/32x32/Man_Brown.png"> <a href="know"><b>Друзья на показ</b></a><br>Узнай что думают о тебе твои друзья...'.div;

echo rowup.'<img src="http://wapmas.ru/pic/ico/dl/66_Icons/36x36/033.png"> <a href="/vipstatus/"><b>Купить VIP статус</b></a><br>Получи больше возможностей с новой функцией...'.div;


echo rowup.'<img src="http://wapmas.ru/pic/ico/dl/66_Icons/36x36/062.png"> <a href="gb/"><b>Гостевая книга</b></a> ('.mysql_result(mysql_query("SELECT COUNT(*) FROM `gb`;"), 0).')<br>Гости и жители сайта,отписались здесь...'.div;

$birth = $db->sql_fetchfield($db->sql_query ("Select count(*) from users where day = '".date("d")."' and month = '".date("m")."'"),0);
echo rowup.'<img src="http://wapmas.ru/pic/ico/dl/Xmas/36x36/002.png"><a href="faq?mod=birthday">Именинники сегодня</a> ('.$birth.')<br/>'.div;

$diaskomm1 = mysql_result(mysql_query("SELECT COUNT(*) FROM `diaskomm1`"), 0);
echo rowup.'<img src="style/icon/z.gif" alt="st"> <a href="stenalov"><b>Стена любви</b></a> (' . $diaskomm1 . ')<br>Признайся в любви своей половинке...'.div;

$wedding = mysql_result(mysql_query("SELECT COUNT(*) FROM `wedding`"), 0);
echo rowup.'<img src="http://wapmas.ru/pic/smiles/love/006.gif"><a href="wedding?">ЗАГС</a> (' . $wedding . ')<br/>Тут творятся бракосочетания...'.div;

$chart = mysql_result(mysql_query("SELECT COUNT(*) FROM `rooms`"), 0);
echo rowup.'<img src="style/icon/c.gif" alt="st"> <a href="chat"><b>Чат</b></a> (' . $chart . ')<br/>
Общайтесь в Веселом чате , найди друзей...'.div;

$telo = mysql_result(mysql_query("SELECT COUNT(*) FROM `telochranitel`"), 0);
echo rowup.'<img src="style/icon/r.gif" alt="st"/> <b><a href="telochranitel/index.php?">Агенство Телохранителей </a></b> (' . $telo . ')<br />Выбери телохранителя и он будет охранять твою анкету...'.div;

echo rowup.'<img src="style/icon/z.gif" alt="st"> <a href="fo"><b>Обмен файлов</b></a> ('.$db->sql_fetchfield($db->sql_query("select count(*)
as num from fo_files"),0).')<br/> Обменивайтесь класными файлами ...'.div;

echo rowup.'<img src="http://wapmas.ru/pic/ico/dl/Free_web_development_icons/24x24/046.png"> <a href="us_shop"><b>Магазин</b></a> (5)<br>То,что можно купить за посты...'.div;

$brend = mysql_result(mysql_query("SELECT COUNT(*) FROM `brand`"), 0);
echo rowup.'<img src="style/icon/b.gif" alt="st"> <a href="brend"><b>Битва брендов</b></a> (' . $brend . ')<br>Докажи,что твой бренд лучше...'.div;

echo rowup.'<img src="style/icon/g.gif" alt="st"> <a href="groups"><b>Группы</b></a> ('.$db->sql_fetchfield($db->sql_query("select count(*) as num from groups"),0).')<br/>
Создовайте любимые группы ...'.div;

echo rowup.'<img src="http://wapmas.ru/pic/ico/dl/66_Icons/36x36/003.png"> <a href="mafia">Онлайн мафия</a><br />Захватывает дух...'.div;

echo rowup.'<img src="style/icon/b.gif" alt="st"> <a href="diaries"><b>Дневники</b></a> ('.$db->sql_fetchfield($db->sql_query("select count(*) as num from diaries"),0).')<br/>
Блоги пользователей ...'.div;
echo rowup.'<img src="style/icon/r.gif" alt="st"> <a href="xren"><b>Информация</b></a><br/>'.div;
echo head0.'<img src="http://wapmas.ru/pic/ico/dl/Coquette_icons_set/32x32/chart.png" alt="st"> Общая статистика Topuz.RU'.div;

echo rowup.'<img src="http://wapmas.ru/pic/ico/dl/Coquette_icons_set/16x16/help.png"> <a href="who"><b><tr>Кто онлайн</tr></b></a> ('.$db->sql_fetchfield($db->sql_query('SELECT COUNT(*) FROM `who`'),0).')<br/>';
$vn=$db->sql_fetchfield($db->sql_query ("select count(*) as num from users WHERE visit>'".date("Y.m.d.")."'"),0);
echo '<img src="http://wapmas.ru/pic/ico/dl/Coquette_icons_set/16x16/next.png"> <a href="faq?mod=last">Сегодня посетили</a> ('.$vn.')<br/>';
$users=$db->sql_fetchfield($db->sql_query("SELECT count(id) FROM users"),0);
echo '<img src="http://wapmas.ru/pic/ico/dl/Coquette_icons_set/16x16/users.png"> <a href="faq?mod=users"><b>Всего юзеров</b></a> ('.$users.')<br/>';
$newtoday=$db->sql_fetchfield($db->sql_query("SELECT count(*) from users WHERE date = '".date("d-m-Y")."'"),0);
echo '<img src="http://wapmas.ru/pic/ico/dl/Coquette_icons_set/16x16/user.png"> <a href="faq?mod=newtoday">Новенькие сегодня</a> ('.$newtoday.')<br/>';
$vip = mysql_result(mysql_query("SELECT COUNT(*) FROM `us_vip`"), 0);
echo '<img src="http://wapmas.ru/pic/ico/dl/66_Icons/16x16/033.png"> <a href="us_vip">VIP пользователей</a> (' . $vip . ')<br>';
$telo = mysql_result(mysql_query("SELECT COUNT(*) FROM `telochranitel`"), 0);
echo '<img src="http://wapmas.ru/pic/ico/dl/66_Icons/16x16/037.png"> <a href="us_oxrana">Наняли охрану</a> (' . $telo . ')'.div;

//echo guser_aut.'Design by <a href="http://4iku.ru"><b>Strannik</b></a>'.div;
//echo gb.'<b><a href="exit">Выход</a></b>'.div;
echo menu.'<b>Реклама</b>'.div;
$query = @mysql_query( "select * from `adv` where `in` = '2' order by `id` asc" );
while( FALSE !== ( $fetch = mysql_fetch_array( $query ) ) )
{
if( !empty( $fetch['color'] ) )
{
$font = '<font color="' . $fetch['color'] . '">';
$cfont = '</font>';
}
else
{
$font = '';
$cfont = '';
}
echo '<a href="http://' . $fetch['url'] . '">' . $font . $fetch['name'] . $cfont . '</a><br/>';
}
echo menu.'<b>Счетчики</b>'.div;
$query = @mysql_query( "select * from `adv` where `in` = '3' order by `id` desc" );
while( FALSE !== ( $fetch = mysql_fetch_array( $query ) ) )
{
echo '<a href="http://' . $fetch['url'] . '"><img src="' . $fetch['img'] . '" alt="' . $fetch['name'] . '" /></a>';
}
echo '<a href="http://waplog.net/c.shtml?443641"><img src="http://c.waplog.net/443641.cnt" alt="waplog" /></a>';
foot();

?>
